MCALF models
************

This sub-package contains:

* Base and sample models that can be adapted and fitted to any spectral
  imaging dataset.
* Models optimised for particular data sets that can be used directly.
* Data structures for storing and exporting the fitted parameters, as
  well as simplifying the calculation of velocities.

.. automodapi:: mcalf.models
   :inherited-members:
